@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *
  * Written By: Ray Strode
  */
@@ -1321,7 +1321,7 @@ on_device_removed (MsdSmartcardManager *manager,
         } else {
                 g_print ("disabling manager for 2 seconds\n");
                 msd_smartcard_manager_stop (manager);
-                g_timeout_add (2000, (GSourceFunc) on_timeout, manager);
+                g_timeout_add_seconds (2, (GSourceFunc) on_timeout, manager);
         }
 }
 
