@@ -42,9 +42,14 @@
 
 #define MATE_DESKTOP_USE_UNSTABLE_API
 
-#include <libmateui/mate-rr-config.h>
-#include <libmateui/mate-rr.h>
-#include <libmateui/mate-rr-labeler.h>
+#include <libmate-desktop/mate-rr-config.h>
+#include <libmate-desktop/mate-rr.h>
+#include <libmate-desktop/mate-rr-labeler.h>
+
+#if GTK_CHECK_VERSION (3, 0, 0)
+#include <libmate-desktop/mate-desktop-utils.h>
+#define gdk_spawn_command_line_on_screen mate_gdk_spawn_command_line_on_screen
+#endif
 
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
